==> dimples-0.5.3.tar.gz: dimples-0.5.3/dimples/client/__init__.py <==
# -*- coding: utf-8 -*-
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Client Module
    ~~~~~~~~~~~~~

"""

from .network import ClientSession
from .network import SessionState

from .archivist import ClientArchivist
from .facebook import ClientFacebook
from .messenger import ClientMessenger
from .packer import ClientMessagePacker
from .processor import ClientMessageProcessor, ClientContentProcessorCreator
from .terminal import Terminal
from .checkpoint import Checkpoint


__all__ = [

    #
    #   Client
    #
    'ClientSession', 'SessionState',

    'ClientArchivist',
    'ClientFacebook', 'ClientMessenger',
    'ClientMessagePacker',
    'ClientMessageProcessor', 'ClientContentProcessorCreator',
    'Terminal',
    'Checkpoint',
]

==> dimples-1.5.2.tar.gz: dimples-1.5.2/dimples/client/__init__.py <==
# -*- coding: utf-8 -*-
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Client Module
    ~~~~~~~~~~~~~

"""

from .network import ClientSession
from .network import SessionState

from .checkpoint import Checkpoint
from .checker import ClientChecker

from .facebook import ClientArchivist
from .facebook import ClientFacebook

from .messenger import ClientMessenger
from .packer import ClientMessagePacker
from .processor import ClientMessageProcessor

from .terminal import Terminal


__all__ = [

    #
    #   Network
    #

    'ClientSession', 'SessionState',

    #
    #   Client
    #

    'Checkpoint',
    'ClientChecker',

    'ClientArchivist',
    'ClientFacebook',

    'ClientMessenger',
    'ClientMessagePacker',
    'ClientMessageProcessor',

    'Terminal',

]
